@@ -1,12 +1,8 @@
 
-context("Poisson regression execution with pscl::hurdle")
-
-# ------------------------------------------------------------------------------
-
-test_that('hurdle', {
+test_that("hurdle", {
   library(pscl)
   data("bioChemists", package = "pscl")
-  hurd <- hurdle(art ~ fem|ment, data = bioChemists)
+  hurd <- hurdle(art ~ fem | ment, data = bioChemists)
   summ <- summary(hurd)
 
   expect_error(counts <- tidy(hurd), regexp = NA)
@@ -29,4 +25,3 @@ test_that('hurdle', {
     both$estimate
   )
 })
-
